@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 #
 #Automated Enrollment script
-# $Id: Autoenroll.pl,v 1.28 2007/12/05 02:04:02 raeburn Exp $
+# $Id: Autoenroll.pl,v 1.29 2008/01/02 03:39:50 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -236,7 +236,7 @@
                     if ( ($enrollvar{$crs}{autostart} < $timenow) && ( ($enrollvar{$crs}{autoend} > $timenow) || ($enrollvar{$crs}{autoend} == 0) ) ) {
                         print $fh &mt('No institutional classlist data could be retrieved for [_1]',$crs)."\n";
                     } else {
-                        print $fh ('Not within time window for auto-enrollment in [_1]',$crs)."\n";
+                        print $fh &mt('Not within time window for auto-enrollment in [_1]',$crs)."\n";
                     }
                 } else {
                     print $fh &mt('Auto-enrollment not currently enabled for [_1]',$crs)."\n";
