@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # implements the tags that control the hints
 #
-# $Id: hint.pm,v 1.62.2.1 2006/12/19 00:52:44 albertel Exp $
+# $Id: hint.pm,v 1.68 2007/05/23 22:36:21 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -32,13 +32,13 @@ use strict;
 use Apache::lonnet();
 use capa;
 use Apache::caparesponse();
+use Apache::lonmaxima();
 use Apache::response();
 use Apache::lonlocal;
 use Storable qw(dclone);
 
-
 BEGIN {
-    &Apache::lonxml::register('Apache::hinttags',('hintgroup','hintpart','numericalhint','stringhint','formulahint','optionhint','radiobuttonhint'));
+    &Apache::lonxml::register('Apache::hinttags',('hintgroup','hintpart','numericalhint','stringhint','formulahint','optionhint','radiobuttonhint','mathhint','customhint'));
 }
 
 
@@ -74,7 +74,6 @@ sub start_hintgroup {
 	my $constructtag=&Apache::edit::get_new_args($token,$parstack,$safeeval,'showoncorrect');
        if ($constructtag) {
            $result =&Apache::edit::rebuild_tag($token);
-           $result.=&Apache::edit::handle_insert();
        }
     }
     @Apache::hint::which=();
@@ -141,7 +140,6 @@ sub start_numericalhint {
 	}
 	if ($constructtag) {
 	    $result  = &Apache::edit::rebuild_tag($token);
-	    $result .= &Apache::edit::handle_insert();
 	}
     } elsif ($target eq 'web') {
 	&Apache::response::reset_params();
@@ -178,7 +176,11 @@ sub end_numericalhint {
 	if (lc($hideunit) eq "yes") { delete($$args_ref{'unit'}); }
 
 	if ($$tagstack[-1] eq 'formulahint') {
-	    $$args_ref{'type'}='fml';
+            if ($$args_ref{'samples'}) {
+                $$args_ref{'type'}='fml';
+            } else {
+                $$args_ref{'type'}='math';
+            }
 	} elsif ($$tagstack[-1] eq 'numericalhint') {
 	    $$args_ref{'type'}='float';
 	}
@@ -229,6 +231,131 @@ sub end_formulahint {
     return &end_numericalhint(@_);
 }
 
+sub start_mathhint {
+    my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
+    #do everything in end, so intervening <responseparams> and <answer> work
+    &Apache::response::start_hintresponse($parstack,$safeeval);
+    &Apache::lonxml::register('Apache::response',('answer'));
+    my $result;
+    if ($target eq 'edit') {
+        $result.=&Apache::edit::tag_start($target,$token);
+        $result.=&Apache::edit::text_arg('Name:','name',$token);
+        $result.=&Apache::edit::select_arg('Algebra System:',
+                                           'cas',
+                                           ['maxima'],
+                                           $token);
+        $result.=&Apache::edit::text_arg('Argument Array:',
+                                         'args',$token);
+        $result.=&Apache::edit::end_row();
+        $result.=&Apache::edit::start_spanning_row();
+    } elsif ($target eq 'modified') {
+        my $constructtag;
+        $constructtag=&Apache::edit::get_new_args($token,$parstack,
+                                                  $safeeval,'name','cas',
+                                                  'args');
+        $result  = &Apache::edit::rebuild_tag($token);
+    } elsif ($target eq 'web') {
+        &Apache::response::reset_params();
+    }
+    return $result;
+}
+
+sub end_mathhint {
+    my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
+    my $result;
+    if ($target eq 'web') {
+        if (!$Apache::lonxml::default_homework_loaded) {
+            &Apache::lonxml::default_homework_load($safeeval);
+        }
+	my $name= &Apache::lonxml::get_param('name',$parstack,$safeeval);
+        &Apache::response::setup_params('mathhint',$safeeval);
+        my $partid=$Apache::inputtags::part;
+        my $submitid=$Apache::inputtags::response[-1];
+        my $response = $Apache::lonhomework::history{
+                            "resource.$partid.$submitid.submission"};
+	
+	my $cas = &Apache::lonxml::get_param('cas',$parstack,$safeeval);
+	my $award;
+	if ($cas eq 'maxima') {
+	    my $args = [&Apache::lonxml::get_param_var('args',$parstack,$safeeval)];
+	    $award=&Apache::lonmaxima::maxima_run($Apache::response::custom_answer[-1],$response,$args);
+	}
+        if ($award eq 'EXACT_ANS' || $award eq 'APPROX_ANS') {
+            push (@Apache::hint::which,$name);
+        }
+        $result='';
+    } elsif ($target eq 'meta') {
+        $result=&Apache::response::meta_package_write($token->[1]);
+    } elsif ($target eq 'edit') {
+        $result.=&Apache::edit::end_row().&Apache::edit::end_table();
+    }
+    pop(@Apache::response::custom_answer);
+    pop(@Apache::response::custom_answer_type);
+    &Apache::response::end_hintresponse();
+    return $result;
+}
+
+sub start_customhint {
+    my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
+    #do everything in end, so intervening <responseparams> and <answer> work
+    &Apache::response::start_hintresponse($parstack,$safeeval);
+    &Apache::lonxml::register('Apache::response',('answer'));
+    my $result;
+    if ($target eq 'edit') {
+        $result.=&Apache::edit::tag_start($target,$token);
+        $result.=&Apache::edit::text_arg('Name:','name',$token);
+        $result.=&Apache::edit::end_row();
+        $result.=&Apache::edit::start_spanning_row();
+    } elsif ($target eq 'modified') {
+        my $constructtag;
+        $constructtag=&Apache::edit::get_new_args($token,$parstack,
+                                                  $safeeval,'name');
+        $result  = &Apache::edit::rebuild_tag($token);
+    } elsif ($target eq 'web') {
+        &Apache::response::reset_params();
+    }
+    return $result;
+}
+
+sub end_customhint {
+    my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
+    my $result;
+    if ($target eq 'web') {
+        if (!$Apache::lonxml::default_homework_loaded) {
+            &Apache::lonxml::default_homework_load($safeeval);
+        }
+	my $name= &Apache::lonxml::get_param('name',$parstack,$safeeval);
+        &Apache::response::setup_params('customhint',$safeeval);
+        my $partid=$Apache::inputtags::part;
+        my $submitid=$Apache::inputtags::response[-1];
+        my $response = $Apache::lonhomework::history{
+                            "resource.$partid.$submitid.submission"};
+        my $award;	
+	if ( $response =~ /[^\s]/ && 
+	     $Apache::response::custom_answer_type[-1] eq 'loncapa/perl') {
+	    if (!$Apache::lonxml::default_homework_loaded) {
+		&Apache::lonxml::default_homework_load($safeeval);
+	    }
+	    ${$safeeval->varglob('LONCAPA::customresponse_submission')}=
+		$response;
+	    
+	    $award = &Apache::run::run('{ my $submission=$LONCAPA::customresponse_submission;'.$Apache::response::custom_answer[-1].'}',$safeeval);
+	}
+        if ($award eq 'EXACT_ANS' || $award eq 'APPROX_ANS') {
+            push (@Apache::hint::which,$name);
+        }
+        $result='';
+    } elsif ($target eq 'meta') {
+        $result=&Apache::response::meta_package_write($token->[1]);
+    } elsif ($target eq 'edit') {
+        $result.=&Apache::edit::end_row().&Apache::edit::end_table();
+    }
+    pop(@Apache::response::custom_answer);
+    pop(@Apache::response::custom_answer_type);
+    &Apache::response::end_hintresponse();
+    return $result;
+}
+
 sub start_stringhint {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
     #do everything in end, so intervening <responseparams> work
@@ -250,7 +377,6 @@ sub start_stringhint {
 						  $safeeval,'name','answer',
 						  'type');
 	$result  = &Apache::edit::rebuild_tag($token);
-	$result .= &Apache::edit::handle_insert();
     } elsif ($target eq 'web') {
 	&Apache::response::reset_params();
     }
@@ -361,7 +487,6 @@ sub start_hintpart {
 						     $safeeval,'on');
 	if ($constructtag) {
 	    $result = &Apache::edit::rebuild_tag($token);
-	    $result.=&Apache::edit::handle_insert();
 	}
     }
     return $result;
@@ -391,7 +516,6 @@ sub start_optionhint {
 						     'answer','concept');
 	if ($constructtag) {
 	    $result  = &Apache::edit::rebuild_tag($token);
-	    $result .= &Apache::edit::handle_insert();
 	}
     } elsif ($target eq 'meta') {
 	$result=&Apache::response::meta_package_write('numericalhint');
@@ -470,7 +594,6 @@ sub start_radiobuttonhint {
 						     'answer');
 	if ($constructtag) {
 	    $result  = &Apache::edit::rebuild_tag($token);
-	    $result .= &Apache::edit::handle_insert();
 	}
     } elsif ($target eq 'meta') {
 	$result=&Apache::response::meta_package_write('numericalhint');
