@@ -1,8 +1,8 @@
-
+#
 # The LearningOnline Network with CAPA
 # image click response style
 #
-# $Id: imageresponse.pm,v 1.83 2007/06/19 20:23:56 banghart Exp $
+# $Id: imageresponse.pm,v 1.91 2007/10/15 20:20:49 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -60,6 +60,18 @@ sub start_imageresponse {
     } elsif ($target eq 'analyze') {
 	my $part_id="$Apache::inputtags::part.$id";
 	push (@{ $Apache::lonhomework::analyze{"parts"} },$part_id);
+	push (@{ $Apache::lonhomework::analyze{"$part_id.bubble_lines"} },
+	      1);
+    } elsif ( $target eq 'edit' ) {
+	$result .= &Apache::edit::tag_start($target,$token).
+	    &Apache::edit::text_arg('Max Number Of Shown Foils:',
+				    'max',$token,'4').
+	    &Apache::edit::end_row().
+	    &Apache::edit::start_spanning_row();
+    } elsif ( $target eq 'modified' ) {
+	my $constructtag=
+	    &Apache::edit::get_new_args($token,$parstack,$safeeval,'max');
+	if ($constructtag) { $result = &Apache::edit::rebuild_tag($token); }
     }
     return $result;
 }
@@ -67,6 +79,9 @@ sub start_imageresponse {
 sub end_imageresponse {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
 
+    my $part_id     = $Apache::inputtags::part;
+    my $response_id = $Apache::inputtags::response[-1]; 
+
     pop(@Apache::lonxml::namespace);
     &Apache::lonxml::deregister('Apache::imageresponse',('foilgroup','foil','text','image','rectangle','conceptgroup'));
 
@@ -82,7 +97,12 @@ sub end_imageresponse {
     
     if ($target eq 'grade' || $target eq 'web' || $target eq 'answer' || 
 	$target eq 'tex' || $target eq 'analyze') {
-	&Apache::lonxml::increment_counter(&Apache::response::repetition());
+	&Apache::lonxml::increment_counter(&Apache::response::repetition(), 
+					   "$part_id.$response_id");
+	if ($target eq 'analyze') {
+	    &Apache::lonhomework::set_bubble_lines();
+	}
+	
     }
     &Apache::response::end_response();
 
@@ -103,36 +123,36 @@ sub getfoilcounts {
     my $max = &Apache::lonxml::get_param('max',$parstack,$safeeval,'-2');
     # +1 since instructors will count from 1
     my $count = $#{ $Apache::response::foilgroup{'names'} }+1;
-    #if (&Apache::response::showallfoils()) { $max=$count; }
+    if (&Apache::response::showallfoils()) { $max=$count; }
     return ($count,$max);
 }
 
 sub whichfoils {
     my ($max)=@_;
-    if (!defined(@{ $Apache::response::foilgroup{'names'} })) { return; }
+    return if (!defined(@{ $Apache::response::foilgroup{'names'} }));
     my @names = @{ $Apache::response::foilgroup{'names'} };
-    my @whichopt =();
+    my @whichopt;
     while ((($#whichopt+1) < $max) && ($#names > -1)) {
 	&Apache::lonxml::debug("Have $#whichopt max is $max");
 	my $aopt;
-#	if (&Apache::response::showallfoils()) {
-#	    $aopt=0;
-#	} else {
+	if (&Apache::response::showallfoils()) {
+	    $aopt=0;
+	} else {
 	    $aopt=int(&Math::Random::random_uniform() * ($#names+1));
-#	}
+	}
 	&Apache::lonxml::debug("From $#names elms, picking $aopt");
 	$aopt=splice(@names,$aopt,1);
 	&Apache::lonxml::debug("Picked $aopt");
-	push (@whichopt,$aopt);
+	push(@whichopt,$aopt);
     }
     return @whichopt;
 }
 
 sub prep_image {
     my ($image,$mode,$name)=@_;
-    my $part=$Apache::inputtags::part;
-    my $respid=$Apache::inputtags::response['-1'];
-    my ($x,$y)=split(/:/,$Apache::lonhomework::history{"resource.$part.$respid.submission"});
+
+    my ($x,$y)= &get_submission($name);
+    &Apache::lonxml::debug("for $name drawing click at $x and $y");
     &draw_image($mode,$image,$x,$y,$Apache::response::foilgroup{"$name.area"});
 }
 
@@ -209,16 +229,16 @@ sub draw_image {
 sub displayfoils {
     my ($target,@whichopt) = @_;
     my $result ='';
-    my $name;
     my $temp=1;
     my @images;
-    foreach $name (@whichopt) {
+    foreach my $name (@whichopt) {
 	$result.=$Apache::response::foilgroup{"$name.text"};
 	&Apache::lonxml::debug("Text is $result");
 	if ($target eq 'tex') {$result.="\\vskip 0 mm \n";} else {$result.="<br />\n";}
 	my $image=$Apache::response::foilgroup{"$name.image"};
 	&Apache::lonxml::debug("image is $image");
-	if ( $target eq 'web' && $image !~ /^http:/ ) {
+	if ( ($target eq 'web' || $target eq 'answer') 
+	     && $image !~ /^http:/ ) {
 	    $image=&clean_up_image($image);
 	}
 	push(@images,$image);
@@ -234,49 +254,64 @@ sub displayfoils {
 	    if ($target eq 'tex') {
 		$result.=$Apache::response::foilgroup{"$name.image"}."\\vskip 0 mm \n";
 	    } else {
-		my $id=$Apache::inputtags::response['-1'];
-		my $token=&prep_image($image);
-		my $temp=1;
-		$result.="<input type=\"image\" name=\"HWVAL_$id:$temp\" ".
-		    "src=\"/adm/randomlabel.png?token=$token\" /><br />\n";
+		my $respid=$Apache::inputtags::response['-1'];
+		my $token=&prep_image($image,'submission',$name);
+		my $input_id = "HWVAL_$respid:$temp";
+		my $id = $env{'form.request.prefix'}.$input_id;
+		$result.='<img onclick="image_response_click(\''.$id.'\',event);"
+	                       src="/adm/randomlabel.png?token='.$token.'" 
+                               id="'.$id.'_imageresponse"
+                                />'.
+			       '<br />'.
+			       '<input type="hidden" name="'.$input_id.'_token" value="'.$token.'" />'.
+			       '<input type="hidden" name="'.$input_id.'" value="'.
+			       join(':',&get_submission($name)).'" />';
 	    }
 	}
 	$temp++;
     }
     if ($target eq 'web') {
 	&Apache::response::setup_prior_tries_hash(\&format_prior_response,
-						  [\@images]);
+						  [\@images,\@whichopt]);
     }
     return $result;
 }
 
 sub format_prior_response {
     my ($mode,$answer,$other_data) = @_;
-    my ($x,$y)=split(/:/,$answer);
-    my $images = $other_data->[0];
-
-    my $token = &draw_image('submission',$images->[0],$x,$y);
-
-    return "<img class=\"LC_prior_image\" src=\"/adm/randomlabel.png?token=$token\" />";
     
+    my $result;
+
+    # make a copy of the data in the refs
+    my @images = @{ $other_data->[0] };
+    my @foils = @{ $other_data->[1] };
+    foreach my $name (@foils) {
+	my $image = pop(@images);
+	my ($x,$y) = &get_submission($name,$answer);
+	my $token = &draw_image('submission',$image,$x,$y);
+	$result .=
+	    '<img class="LC_prior_image"
+                  src="/adm/randomlabel.png?token='.$token.'" /><br />';
+    }
+    return $result;
 }
 
 sub display_answers {
     my ($target,$whichopt)=@_;
 
-    my $result;
+    my $result=&Apache::response::answer_header('imageresponse');
     foreach my $name (@$whichopt) {
 	my $image=$Apache::response::foilgroup{"$name.image"};
 	&Apache::lonxml::debug("image is $image");
-	if ( $target eq 'web' && $image !~ /^http:/ ) {
+	if ( ($target eq 'web' || $target eq 'answer')
+	     && $image !~ /^http:/ ) {
 	    $image = &clean_up_image($image);
 	} 
 	my $token=&prep_image($image,'answeronly',$name);
 
-	$result.=&Apache::response::answer_header('imageresponse');
 	$result.=&Apache::response::answer_part('imageresponse',"<img src=\"/adm/randomlabel.png?token=$token\" /><br />\n");
-	$result.=&Apache::response::answer_footer('imageresponse');
     }
+    $result.=&Apache::response::answer_footer('imageresponse');
     return $result;
 }
 
@@ -311,13 +346,12 @@ sub gradefoils {
 	return;
     }
     
-    my $x;
-    my $y;
-    my $result;
+    my @results;
     my $temp=1;
+    my %response;
     foreach my $name (@whichopt) {
-	$x=$env{"form.HWVAL_$id:$temp.x"};
-	$y=$env{"form.HWVAL_$id:$temp.y"};
+	my ($x,$y) = split(':',$env{"form.HWVAL_$id:$temp"});
+	$response{$name} = $env{"form.HWVAL_$id:$temp"};
 	&Apache::lonxml::debug("Got a x of $x and a y of $y for $name");
 	if (defined($x) && defined($y) &&
 	    defined(@{ $Apache::response::foilgroup{"$name.area"} })) {
@@ -338,23 +372,53 @@ sub gradefoils {
 		if ($grade eq 'APPROX_ANS') { last; }
 	    }
 	    &Apache::lonxml::debug("Foil was $grade");
-	    if ($grade eq 'INCORRECT') { $result= 'INCORRECT'; }
-	    if (($grade eq 'APPROX_ANS') && ($result ne 'APPROX_ANS')) { $result=$grade; }
-	    &Apache::lonxml::debug("Question is $result");
-	    $temp++;
+	    push(@results, $grade)
+	} else {
+	    push(@results, 'MISSING_ANSWER')
 	}
+	$temp++;
     }
-    my $responsestr="$x:$y";
+    my ($result) = &Apache::inputtags::finalizeawards(\@results,[]);
+    &Apache::lonxml::debug("Question is $result");
+
     my $part=$Apache::inputtags::part;
-    my %previous=&Apache::response::check_for_previous($responsestr,$part,$id);
+    my %previous=
+	&Apache::response::check_for_previous(&stringify_submission(\%response),
+					      $part,$id);
     if ($result 
 	&& $Apache::lonhomework::type eq 'survey') { $result='SUBMITTED'; }
     &Apache::response::handle_previous(\%previous,$result);
-    $Apache::lonhomework::results{"resource.$part.$id.submission"}=$responsestr;
+    $Apache::lonhomework::results{"resource.$part.$id.submission"}=
+	&stringify_submission(\%response);
     $Apache::lonhomework::results{"resource.$part.$id.awarddetail"}=$result;
     return;
 }
 
+sub stringify_submission {
+    my ($response) = @_;
+    return &Apache::lonnet::hash2str(%{ $response });
+
+    
+}
+
+sub get_submission {
+    my ($name,$string) = @_;
+
+    if (!defined($string)) {
+	my $part=$Apache::inputtags::part;
+	my $respid=$Apache::inputtags::response['-1'];
+   	$string = 
+	    $Apache::lonhomework::history{"resource.$part.$respid.submission"};
+    }
+
+    if ($string !~ /=/) {
+	return split(':',$string);
+    } else {
+	my %response = &Apache::lonnet::str2hash($string);
+	return split(':',$response{$name});
+    }
+}
+
 sub end_foilgroup {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
     my $result='';
@@ -437,7 +501,7 @@ sub start_foil {
 	}
 	$Apache::response::foilnames{$name}++;
 	if ( $Apache::imageresponse::conceptgroup
-	     #&& !&Apache::response::showallfoils()
+	     && !&Apache::response::showallfoils()
 	     ) {
 	    push(@{ $Apache::response::conceptgroup{'names'} }, $name);
 	} else {
@@ -490,7 +554,7 @@ sub end_text {
 	|| $target eq 'answer') {
 	my $name = $Apache::imageresponse::curname;
 	if ( $Apache::imageresponse::conceptgroup
-	     #&& !&Apache::response::showallfoils()
+	     && !&Apache::response::showallfoils()
 	     ) {
 	    $Apache::response::conceptgroup{"$name.text"} = &Apache::lonxml::endredirection;
 	} else {
@@ -533,7 +597,7 @@ sub end_image {
 	my $image = &Apache::lonxml::endredirection();
 	&Apache::lonxml::debug("original image is $image");
 	if ( $Apache::imageresponse::conceptgroup
-	     #&& !&Apache::response::showallfoils()
+	     && !&Apache::response::showallfoils()
 	     ) {
 	    $Apache::response::conceptgroup{"$name.image"} = $image;
 	} else {
@@ -542,7 +606,7 @@ sub end_image {
     } elsif ($target eq 'analyze') {
 	my $image = &Apache::lonxml::endredirection();
 	if ( $Apache::imageresponse::conceptgroup
-	     #&& !&Apache::response::showallfoils()
+	     && !&Apache::response::showallfoils()
 	     ) {
 	    $Apache::response::conceptgroup{"$name.image"} = $image;
 	} else {
@@ -622,7 +686,7 @@ sub end_rectangle {
 	$area=~s/\s//g;
 	&Apache::lonxml::debug("out is $area for $name");
 	if ( $Apache::imageresponse::conceptgroup
-	     #&& !&Apache::response::showallfoils()
+	     && !&Apache::response::showallfoils()
 	     ) {
 	    push @{ $Apache::response::conceptgroup{"$name.area"} },"rectangle:$area";
 	} else {
@@ -703,7 +767,7 @@ sub end_polygon {
 	$area=~s/\s*//g;
 	&Apache::lonxml::debug("out is $area for $name");
 	if ( $Apache::imageresponse::conceptgroup
-	     #&& !&Apache::response::showallfoils()
+	     && !&Apache::response::showallfoils()
 	     ) {
 	    push @{ $Apache::response::conceptgroup{"$name.area"} },"polygon:$area";
 	} else {
