@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # input  definitons
 #
-# $Id: inputtags.pm,v 1.231 2007/09/26 19:30:30 albertel Exp $
+# $Id: inputtags.pm,v 1.235 2007/11/17 02:03:46 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -539,8 +539,29 @@ sub valid_award {
     $i=0;
     my %rev_awards = map { ($_,$i++) } @awards;
 
+sub awarddetail_to_awarded {
+    my ($awarddetail) = @_;
+    if ($awarddetail eq 'EXACT_ANS'
+	|| $awarddetail eq 'APPROX_ANS') {
+	return 1;
+    }
+    return 0;
+}
+
+sub hide_award {
+    my ($award) = @_;
+    if (&Apache::lonhomework::show_no_problem_status()) {
+	return 1;
+    }
+    if ($award =~
+	/^(?:EXACT_ANS|APPROX_ANS|SUBMITTED|ASSIGNED_SCORE|INCORRECT)/) {
+	return 1;
+    }
+    return 0;
+}
+
 sub finalizeawards {
-    my ($awardref,$msgref,$nameref,$reverse)=@_;
+    my ($awardref,$msgref,$nameref,$reverse,$final_scantron)=@_;
     my $result;
     if ($#$awardref == -1) { $result = "NO_RESPONSE"; }
     if ($result eq '' ) {
@@ -551,10 +572,29 @@ sub finalizeawards {
 		$blankcount++;
 	    }
 	}
-	if ($blankcount == ($#$awardref + 1)) { $result = 'NO_RESPONSE'; }
+	if ($blankcount == ($#$awardref + 1)) {
+	    return ('NO_RESPONSE');
+	}
     }
-    if (defined($result)) { return ($result); }
+    if (!$final_scantron && defined($result)) { return ($result); }
 
+    # if in scantron mode, if the award for any response is 
+    # assigned score, then the part gets an assigned score
+    if ($final_scantron 
+	&& grep {$_ eq 'ASSIGNED_SCORE'} (@$awardref)) {
+	return ('ASSIGNED_SCORE');
+    }
+
+    # if in scantron mode, if the award for any response is 
+    # correct and there are non-correct responses,
+    # then the part gets an assigned score
+    if ($final_scantron 
+	&& (grep { $_ eq 'EXACT_ANS' ||
+		   $_ eq 'APPROX_ANS'  } (@$awardref))
+	&& (grep { $_ ne 'EXACT_ANS' &&
+		   $_ ne 'APPROX_ANS'  } (@$awardref))) {
+	return ('ASSIGNED_SCORE');
+    }
     # these awards are ordered from most important error through best correct
     my $awards = (!$reverse) ? \%fwd_awards : \%rev_awards ;
 
@@ -568,6 +608,7 @@ sub finalizeawards {
 	}
 	$j++;
     }
+
     if (defined($which)) {
 	if (ref($nameref)) {
 	    return ($$awardref[$which],$$msgref[$which],$$nameref[$which]);
@@ -626,14 +667,17 @@ sub decideoutput {
 		$message.= $computer;
 	    }
 	    $added_computer_text=1;
-	    my ($symb) = &Apache::lonnet::whichuser();
-	    if (($symb ne '') 
-		&&
-		($env{'course.'.$env{'request.course.id'}.
-			    '.disable_receipt_display'} ne 'yes')) { 
-		$message.=(($target eq 'web')?'<br />':' ').
-		    &mt('Your receipt is').' '.&Apache::lonnet::receipt($Apache::inputtags::part).
-		    (($target eq 'web')?&Apache::loncommon::help_open_topic('Receipt'):'');
+	    if ($awarded > 0) {
+		my ($symb) = &Apache::lonnet::whichuser();
+		if (($symb ne '') 
+		    &&
+		    ($env{'course.'.$env{'request.course.id'}.
+			      '.disable_receipt_display'} ne 'yes')) { 
+		    $message.=(($target eq 'web')?'<br />':' ').
+			&mt('Your receipt is [_1]',
+			    (&Apache::lonnet::receipt($Apache::inputtags::part).
+			     (($target eq 'web')?&Apache::loncommon::help_open_topic('Receipt'):'')));
+		}
 	    }
 	}
 	$button=0;
@@ -660,12 +704,14 @@ sub decideoutput {
 		$message.= $computer;
 	    }
 	    $added_computer_text=1;
-	    unless ($env{'course.'.
+	    if  ($awarded > 0 
+		 && $env{'course.'.
 			     $env{'request.course.id'}.
-			     '.disable_receipt_display'} eq 'yes') { 
+			     '.disable_receipt_display'} ne 'yes') { 
 		$message.=(($target eq 'web')?'<br />':' ').
-		    'Your receipt is '.&Apache::lonnet::receipt($Apache::inputtags::part).
-		    (($target eq 'web')?&Apache::loncommon::help_open_topic('Receipt'):'');
+		    &mt('Your receipt is [_1]',
+			(&Apache::lonnet::receipt($Apache::inputtags::part).
+			 (($target eq 'web')?&Apache::loncommon::help_open_topic('Receipt'):'')));
 	    }
 	    $css_class=$possible_class{'correct'};
 	    $button=0;
@@ -786,8 +832,9 @@ sub decideoutput {
 	}
     }
 
-    if (lc($Apache::lonhomework::problemstatus) eq 'no'  && 
-	$Apache::inputtags::status[-1] ne 'SHOW_ANSWER') {
+    if (&Apache::lonhomework::hide_problem_status()
+	&& $Apache::inputtags::status[-1] ne 'SHOW_ANSWER'
+	&& &hide_award($award)) {
 	$message = &mt("Answer Submitted: Your final submission will be graded after the due date.");
 	$css_class=$possible_class{'no_grade'};
 	$button=1;
@@ -850,8 +897,9 @@ sub setgradedata {
 	$Apache::lonhomework::results{"resource.$id.afterduedate"}=$award;
 	return '';
     } elsif ( $Apache::lonhomework::history{"resource.$id.solved"} !~
-	      /^correct/ || $Apache::lonhomework::scantronmode ||
-	      lc($Apache::lonhomework::problemstatus) eq 'no') {
+	      /^correct/ 
+	      || $Apache::lonhomework::scantronmode 
+	      || &Apache::lonhomework::hide_problem_status()  ) {
         # the student doesn't already have it correct,
 	# or we are in a mode (scantron orno problem status) where a correct 
         # can become incorrect
@@ -873,8 +921,13 @@ sub setgradedata {
 	    my $numawards=scalar(@Apache::inputtags::response);
 	    $Apache::lonhomework::results{"resource.$id.awarded"} = 0;
 	    foreach my $res (@Apache::inputtags::response) {
-		$Apache::lonhomework::results{"resource.$id.awarded"}+=
-		    $Apache::lonhomework::results{"resource.$id.$res.awarded"};
+		if (defined($Apache::lonhomework::results{"resource.$id.$res.awarded"})) {
+		    $Apache::lonhomework::results{"resource.$id.awarded"}+=
+			$Apache::lonhomework::results{"resource.$id.$res.awarded"};
+		} else {
+		    $Apache::lonhomework::results{"resource.$id.awarded"}+=
+			&awarddetail_to_awarded($Apache::lonhomework::results{"resource.$id.$res.awarddetail"});
+		}
 	    }
 	    if ($numawards > 0) {
 		$Apache::lonhomework::results{"resource.$id.awarded"}/=
@@ -889,8 +942,8 @@ sub setgradedata {
 	} elsif ( $award eq 'INCORRECT' ) {
 	    $Apache::lonhomework::results{"resource.$id.tries"} =
 		$Apache::lonhomework::history{"resource.$id.tries"} + 1;
-	    if (lc($Apache::lonhomework::problemstatus) eq 'no' ||
-		$Apache::lonhomework::scantronmode) {
+	    if (&Apache::lonhomework::hide_problem_status()
+		|| $Apache::lonhomework::scantronmode) {
 		$Apache::lonhomework::results{"resource.$id.awarded"} = 0;
 	    }
 	    $Apache::lonhomework::results{"resource.$id.solved"} =
@@ -909,12 +962,18 @@ sub setgradedata {
 	} else {
 	    $Apache::lonhomework::results{"resource.$id.solved"} =
 		'incorrect_attempted';
-	    if (lc($Apache::lonhomework::problemstatus) eq 'no' ||
-		$Apache::lonhomework::scantronmode) {
+	    if (&Apache::lonhomework::show_no_problem_status()
+		|| $Apache::lonhomework::scantronmode) {
 		$Apache::lonhomework::results{"resource.$id.tries"} =
 		    $Apache::lonhomework::history{"resource.$id.tries"} + 1;
 		$Apache::lonhomework::results{"resource.$id.awarded"} = 0;
 	    }
+
+	    if (&Apache::lonhomework::show_some_problem_status()) {
+		# clear out the awarded if they had gotten it wrong/right
+		# and are now in an error mode	
+		$Apache::lonhomework::results{"resource.$id.awarded"} = '';
+	    }
 	}
 	if (defined($msg)) {
 	    $Apache::lonhomework::results{"resource.$id.awardmsg"} = $msg;
@@ -928,7 +987,7 @@ sub setgradedata {
 	    # check if this was a previous submission if it was delete the
 	    # unneeded data and update the previously_used attribute
 	    if ( $previously_used eq 'PREVIOUSLY_USED') {
-		if (lc($Apache::lonhomework::problemstatus) ne 'no') {
+		if (&Apache::lonhomework::show_problem_status()) {
 		    delete($Apache::lonhomework::results{"resource.$id.tries"});
 		    $Apache::lonhomework::results{"resource.$id.previous"} = '1';
 		}
@@ -1006,7 +1065,9 @@ sub grade {
 	    &Apache::lonxml::debug("got message $value from $response for $id");
 	    push (@msgs,$value);
 	}
-	my ($finalaward,$msg) = &finalizeawards(\@awards,\@msgs);
+	my ($finalaward,$msg) = 
+	    &finalizeawards(\@awards,\@msgs,undef,undef,
+			    $Apache::lonhomework::scantronmode);
 	my $previously_used;
 	if ( $#Apache::inputtags::previous eq $#awards ) {
 	    my ($match) =
@@ -1185,7 +1246,7 @@ sub previous_tries {
 	    my $previous = $count_lookup{$which};
 	    $message =~ s{(</td>)}{ as submission \# $previous $1};
 	} elsif ($Apache::lonhomework::history{"$prefix.tries"}) {
-	    if (!(lc($Apache::lonhomework::problemstatus) eq 'no'
+	    if (!(&Apache::lonhomework::hide_problem_status()
 		  && $Apache::inputtags::status[-1] ne 'SHOW_ANSWER')
 		&& $Apache::lonhomework::history{"$prefix.solved"} =~/^correct/
 		) {
@@ -1243,7 +1304,7 @@ sub previous_tries {
     my $prefix = $env{'form.request.prefix'};
     $prefix =~ tr{.}{_};
     my $function_name = "LONCAPA_previous_tries_".$prefix.
-	$Apache::lonxml::curdepth;
+	$Apache::lonxml::curdepth.'_'.$env{'form.counter'};
     my $result ="<script type=\"text/javascript\">
 // <![CDATA[
     function $function_name() {newWindow=open('','new_W','width=500,height=500,scrollbars=1,resizable=yes');newWindow.$windowopen;newWindow.document.writeln('$start_page $output $end_page');newWindow.document.close();newWindow.focus()}
