@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Quick Student Grades Display
 #
-# $Id: lonquickgrades.pm,v 1.40 2006/03/15 22:11:04 albertel Exp $
+# $Id: lonquickgrades.pm,v 1.41 2007/12/20 10:18:19 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -92,7 +92,7 @@ score sheet</a>.</p>
 HEADER
     }
 
-    $r->print("This may take a few moments to display.");
+    $r->print(&mt('This may take a few moments to display.'));
 
     $r->rflush();
 
@@ -275,8 +275,8 @@ HEADER
 	my $maxHelpLink = Apache::loncommon::help_open_topic("Quick_Grades_Possibly_Correct");
 
 	$title = $showPoints ? "Points" : "Parts Done";
-	
-	$r->print("<tr><td colspan='2' align='right'>Total $title: <b>$totalRight</b><br>");
+	my $totaltitle = $showPoints ? &mt("Awarded Total Points") : &mt("Total Parts Done");
+	$r->print("<tr><td colspan='2' align='right'>$totaltitle: <b>$totalRight</b><br>");
 	$r->print(&mt("Max Possible To Date")." $maxHelpLink: <b>$totalPossible</b><br>");
 	$title = $showPoints ? "Points" : "Parts";
 	$r->print(&mt("Total $title In Course").": <b>$totalParts</b></td></tr>\n\n");
