@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 # CGI-script to run LaTeX, dvips, ps2ps, ps2pdf etc.
 #
-# $Id: printout.pl,v 1.127 2007/09/21 21:11:20 albertel Exp $
+# $Id: printout.pl,v 1.128 2007/10/11 22:49:49 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -166,7 +166,7 @@ END
 my %perlvar=%{&LONCAPA::Configuration::read_conf('loncapa.conf')};
  &Apache::lonlocal::get_language_handle();
  &Apache::loncommon::content_type(undef,'text/html');
-
+$env{'request.noversionuri'} = '/cgi-bin/printout.pl';
   print(&Apache::loncommon::start_page('Creating PDF'));
 
   my $identifier = $ENV{'QUERY_STRING'};
@@ -187,9 +187,10 @@ my %perlvar=%{&LONCAPA::Configuration::read_conf('loncapa.conf')};
   if ($student_names=~/_END_/) {  
       @names_pack=split(/_ENDPERSON_/,$student_names);
   }
-
-print "<a href=\"$backref\"><b>Return</b></a> to last resource.<br /><br />";
-
+  if ($backref) {
+      print('<p>'.&mt("[_1]Return[_2] to editing resource.",
+		      "<a href=\"$backref\"><b>","</b></a>").'</p>');
+  }
   my $figfile = $texfile;
   $figfile =~ s/^(.*_printout)_\d+_\d+_\d+\.tex/$1\.dat/;
   my $duefile = $texfile;
