@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Replication Manager
 #
-# $Id: lonrep.pm,v 1.13 2007/04/26 01:18:47 albertel Exp $
+# $Id: lonrep.pm,v 1.14 2007/10/02 01:09:53 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -32,7 +32,6 @@ use strict;
 use Apache::Constants qw(:common :http);
 use Apache::lonnet;
 use Apache::File();
-use CGI::Cookie();
 
 sub update_filename {
     my ($r,$filename) = @_;
@@ -84,10 +83,9 @@ sub handler {
 	      }
               return OK;
           }
-          my %cookies=CGI::Cookie->parse($r->header_in('Cookie'));
-          my $lonid=$cookies{'lonID'};
-          if ($lonid) {
-	     $r->log_reason('Replication failed for '.$lonid->value);
+          my $handle = &Apache::lonnet::check_for_valid_session($r);
+          if ($handle) {
+	     $r->log_reason('Replication failed for '.$handle);
              return $response;
 	  } else {
 	     $r->log_reason('Replication failed for unknown user'); 
