@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: startup.pl,v 1.31 2007/11/19 23:13:27 albertel Exp $
+# $Id: startup.pl,v 1.32 2007/12/23 04:41:19 raeburn Exp $
 
 BEGIN {
     eval "use Apache2::compat();";
@@ -62,7 +62,6 @@ use Apache::lonquickgrades();
 use Apache::lonaboutme();
 use Apache::lonannounce();
 use Apache::lonbulletin();
-use Apache::londropadd();
 use Apache::lonerrorhandler();
 use Apache::lonevaluate();
 use Apache::lonfeedback();
@@ -144,6 +143,7 @@ use Apache::lonpickcourse();
 use Apache::longroup();
 use Apache::groupboards();
 use Apache::lonclonecourse();
+use Apache::lonuserutils();
 1;
 __END__
 
