@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Wrapper for external and binary files as standalone resources
 #
-# $Id: lonwrapper.pm,v 1.25 2006/11/30 23:35:38 banghart Exp $
+# $Id: lonwrapper.pm,v 1.26 2006/12/20 22:42:48 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -122,7 +122,7 @@ sub handler {
     $orgurl.=(($orgurl=~/\?/)?'&':'?').'wrapperdisplay=menu';
     $url=~s/^\/adm\/wrapper//;
     my $is_ext = $url =~ m|^/ext/|;
-    $url=~s/^\/ext\//http\:\/\//;
+    $url=~s{^/ext/}{http://};
     $url=~s|http://https://|https://|;
     $url=~s|&colon;|:|g;
 #
